@@ -783,9 +783,6 @@ instance Arbitrary a => Arbitrary (Product a) where
 instance Arbitrary a => Arbitrary (Sum a) where
    arbitrary = fmap Sum arbitrary
 
-instance Arbitrary a => Arbitrary (Vector a) where
-   arbitrary = fmap fromList arbitrary
-
 instance Arbitrary ByteStringUTF8 where
    arbitrary = fmap ByteStringUTF8 arbitrary
 
@@ -825,9 +822,6 @@ instance CoArbitrary a => CoArbitrary (Product a) where
 instance CoArbitrary a => CoArbitrary (Sum a) where
    coarbitrary (Sum a) = coarbitrary a
 
-instance CoArbitrary a => CoArbitrary (Vector a) where
-   coarbitrary = coarbitrary . toList
-
 instance CoArbitrary ByteStringUTF8 where
    coarbitrary (ByteStringUTF8 bs) = coarbitrary bs
 
